package main

import (
	"converge/pkg/models"
	"converge/pkg/server/converge"
	"net/http"
	"regexp"
	"strings"
)

func getConvergeAccess(r *http.Request) models.ConvergeAccess {

	pattern := regexp.MustCompile("^(.*)/usage$")
	matches := pattern.FindStringSubmatch(r.URL.Path)
	contextPath := ""
	if len(matches) == 2 {
		contextPath = matches[1]
	}

	secure := ""
	if r.TLS == nil {
		secure = ""
	} else {
		secure = "s"
	}
	for _, header := range []string{"X-Forwarded-Proto", "X-Scheme", "X-Forwarded-Scheme"} {
		values := r.Header.Values(header)
		for _, value := range values {
			if strings.ToLower(value) == "https" {
				secure = "s"
			}
		}
	}

	location, err := converge.GetUserLocation(r)
	if err != nil {
		panic(err)
	}
	baseUrl := strings.ReplaceAll(r.Host+contextPath, "//", "/")
	return models.ConvergeAccess{
		Secure:   secure,
		BaseUrl:  baseUrl,
		Location: location,
	}
}
